@@ -6,7 +6,6 @@
 #' @param y \code{NULL} (default) or a numeric vector with compatible dimsensions to \code{x}.
 #' @param asym logical; \code{FALSE} (default) Allows for asymmetrical dependencies.
 #' @param print.map logical; \code{FALSE} (default) Plots quadrant means.
-#' @param ncores integer; value specifying the number of cores to be used in the parallelized  procedure. If NULL (default), the number of cores to be used is equal to the number of cores of the machine - 1.
 #' @return Returns the bi-variate \code{"Correlation"} and \code{"Dependence"} or correlation / dependence matrix for matrix input.
 #' @note p-values and confidence intervals can be obtained from sampling random permutations of \code{y_p} and running \code{NNS.dep(x,y_p)} to compare against a null hypothesis of 0 correlation or independence between \code{x,y}.
 #'
@@ -75,8 +74,7 @@
 NNS.dep = function(x,
                    y = NULL,
                    asym = FALSE,
-                   print.map = FALSE,
-                   ncores = NULL){
+                   print.map = FALSE){
 
   oldw <- getOption("warn")
   options(warn = -1)
@@ -97,12 +95,6 @@ NNS.dep = function(x,
     }
 
 
-    if (is.null(ncores)) {
-      num_cores <- detectCores() - 1
-    } else {
-      num_cores <- ncores
-    }
-
     l <- length(x)
 
     segs <- list(5L)
@@ -137,6 +129,9 @@ NNS.dep = function(x,
     nns.dep <- list(5L)
 
     if(any(unlist(uniques)==1)){
+      weights <- c(1/3, 1/3, 1/3)
+      nns.dep <- list(3L)
+
       DT <- data.table::data.table(x, y)
       data.table::setkey(DT[, x := x], x)
 
@@ -156,6 +151,7 @@ NNS.dep = function(x,
 
     options(warn = oldw)
 
+
     return(list("Correlation" = sum(weights * unlist(lapply(nns.dep, `[[`, 1))),
                 "Dependence" = sum(weights * unlist(lapply(nns.dep, `[[`, 2)))))
 
