@@ -54,13 +54,10 @@ NNS.dep.base <- function(x,
     n <- length(x)
     if(asym){type <- "XONLY"} else {type <- NULL}
 
-    if (print.map == TRUE) {
-      part.map <- NNS.part(x, y, order = order, type = type, noise.reduction = "mean", obs.req = NULL,
-                           Voronoi = TRUE, min.obs.stop = TRUE)
-    } else {
-      part.map <- NNS.part(x, y, order = order, type = type, noise.reduction = "mean", obs.req = NULL,
+
+    part.map <- NNS.part(x, y, order = order, type = type, noise.reduction = "mean", obs.req = NULL,
                            Voronoi = FALSE, min.obs.stop = TRUE)
-    }
+
 
     part.df <- part.map$dt
 
@@ -120,18 +117,12 @@ NNS.dep.base <- function(x,
       min_part.df[, `:=` (weight = .N/n), by = quadrant]
 
       if(asym){
-        disp <- min_part.df[,"nns_results" := ifelse(abs(cor(x,abs(y))) < .3, (sign(cor(x,abs(y)))*(1 - min(1, abs(sd(abs(y))/sd_var)))),
-                                               (sign(cor(x,abs(y)))*summary(lm(abs(y)~x))$r.squared)), by = quadrant]
-
-        disp <- disp[, nns_results[1], by  = quadrant]$V1
-
+          disp <- min_part.df[,"nns_results" := sign(cor(x,abs(y)))*summary(lm(abs(y)~x))$r.squared, by = quadrant]
       } else {
-         disp <- min_part.df[,"nns_results" := ifelse(abs(cor(x,y)) < .3, (sign(cor(x,y))*(1 - min(1, abs(sd(y)/sd_var)))),
-                                     (sign(cor(x,y))*summary(lm(y~x))$r.squared)), by = quadrant]
-
-         disp <- disp[, nns_results[1], by  = quadrant]$V1
-         }
+          disp <- min_part.df[,"nns_results" := sign(cor(x,y))*summary(lm(y~x))$r.squared, by = quadrant]
+      }
 
+      disp <- disp[, nns_results[1], by  = quadrant]$V1
       disp[is.na(disp)] <- 0
 
       nns.cor <- sum(disp * min_part.df[, weight[1], by = quadrant]$V1)
