@@ -24,7 +24,8 @@
 #' @param noise.reduction the method of determining regression points options: ("mean", "median", "mode", "off"); In low signal:noise situations,\code{(noise.reduction = "mean")}  uses means for \link{NNS.dep} restricted partitions, \code{(noise.reduction = "median")} uses medians instead of means for \link{NNS.dep} restricted partitions, while \code{(noise.reduction = "mode")}  uses modes instead of means for \link{NNS.dep} restricted partitions.  \code{(noise.reduction = "off")} uses an overall central tendency measure for partitions.
 #' @param dist options:("L1", "L2", "DTW", "FACTOR") the method of distance calculation; Selects the distance calculation used. \code{dist = "L2"} (default) selects the Euclidean distance and \code{(dist = "L1")} seclects the Manhattan distance; \code{(dist = "DTW")} selects the dynamic time warping distance; \code{(dist = "FACTOR")} uses a frequency.
 #' @param ncores integer; value specifying the number of cores to be used in the parallelized  procedure. If NULL (default), the number of cores to be used is equal to the number of cores of the machine - 1.
-#' @param multivariate.call Internal parameter for multivariate regressions.
+#' @param multivariate.call Internal argument for multivariate regressions.
+#' @param point.only Internal argument for abbreviated output.
 #' @return UNIVARIATE REGRESSION RETURNS THE FOLLOWING VALUES:
 #' \itemize{
 #'  \item{\code{"R2"}} provides the goodness of fit;
@@ -131,6 +132,7 @@ NNS.reg = function (x, y,
                     n.best = NULL,
                     noise.reduction = "off",
                     dist = "L2", ncores = NULL,
+                    point.only = FALSE,
                     multivariate.call = FALSE){
 
   oldw <- getOption("warn")
@@ -185,13 +187,13 @@ NNS.reg = function (x, y,
     }
   }
 
-  if(factor.2.dummy && !multivariate.call){
+  if(factor.2.dummy){# && !multivariate.call){
     if(is.list(x) & !is.data.frame(x)){
       x <- do.call(cbind, x)
     }
 
     if(!is.null(point.est)){
-      if(!is.null(dim(x))){
+      if(!is.null(dim(x)) && dim(x)[2]>1){
         if(is.null(dim(point.est))) point.est <- data.frame(t(point.est)) else point.est <- data.frame(point.est)
         new_x <- data.table::rbindlist(list(data.frame(x), point.est), use.names = FALSE)
       } else {
@@ -200,7 +202,7 @@ NNS.reg = function (x, y,
     }
 
 
-    if(!is.null(dim(x))){
+    if(!is.null(dim(x)) && dim(x)[2]>1){
       x <- do.call(cbind, lapply(data.frame(x), factor_2_dummy_FR))
     } else {
       x <- factor_2_dummy_FR(x)
@@ -211,7 +213,7 @@ NNS.reg = function (x, y,
     if(!is.null(point.est)){
       point.est.y <- numeric()
 
-      if(!is.null(dim(x))){
+      if(!is.null(dim(x)) && dim(x)[2]>1){
         new_x <- do.call(cbind, lapply(data.frame(new_x), factor_2_dummy_FR))
       } else {
         new_x <- factor_2_dummy_FR(new_x)
@@ -293,10 +295,10 @@ NNS.reg = function (x, y,
                          residual.plot = residual.plot, order = order, n.best = n.best, type = type,
                          location = location, noise.reduction = noise.reduction,
                          dist = dist, stn = stn, return.values = return.values, plot.regions = plot.regions,
+                         point.only = point.only,
                          ncores = ncores))
 
       } else { # Multivariate dim.red == FALSE
-
         if(is.null(original.names)){
           colnames.list <- list()
           for(i in 1 : ncol(x)){
@@ -424,17 +426,17 @@ NNS.reg = function (x, y,
   } # Multivariate
 
   if(all(x == 1:length(x))) asymmetry <- FALSE else asymmetry <- TRUE
+
   dependence <- NNS.dep(x, y, print.map = FALSE, asym = asymmetry)$Dependence
   dependence[is.na(dependence)] <- .01
 
-
   if(is.null(original.columns) || is.null(dim.red.method)){
     synthetic.x.equation <- NULL
     x.star <- NULL
   }
 
   if(is.null(order)){
-    dep.reduced.order <- max(1, ifelse( (ceiling(log(length(y), 2)) * dependence)%%1 < .5 ,
+    dep.reduced.order <- max(1, ifelse( ((log(length(y), 2)) * dependence)%%1 < .5 ,
                                         floor(ceiling(log(length(y),2)) * dependence),
                                         ceiling(ceiling(log(length(y),2)) * dependence)))
   } else {
@@ -442,7 +444,6 @@ NNS.reg = function (x, y,
   }
 
 
-
   if(dependence > stn){
     part.map <- NNS.part(x, y, type = NULL, noise.reduction = noise.reduction, order = dep.reduced.order, obs.req = 0, min.obs.stop = FALSE)
     if(length(part.map$regression.points$x) == 0){
@@ -514,23 +515,21 @@ NNS.reg = function (x, y,
 
 
     ### Endpoints
-    if(l_x.mid.min_unique > 1){
+    if(l_x.mid.min_unique > 1 && l_y.min > 5){
       if(dependence < stn){
         if(!is.null(type)){
           Dynamic.average.mid.min <- mode_class(y.min)
           x0 <- mode_class(y.min)
         } else {
-
           Dynamic.average.mid.min <- tryCatch(lm(y[which(x <= min.range)] ~ 0 + x[which(x <= min.range)], offset = rep(head(regression.points$y, 1), length(y[which(x <= min.range)])))$fitted[which.max(x[which(x <= min.range)])]  + (mid.min.range - max(x[which(x <= min.range)])) * lm(y[which(x <= min.range)] ~  0 + x[which(x <= min.range)], offset = rep(head(regression.points$y, 1), length(y[which(x <= min.range)])) )$coef[1],
                                               error = function(e) NA)
-          if(l_y.min>1 && l_y.mid.min>1){
-            x0 <- sum(lm((y[which(x <= min.range)]) ~  (x[which(x <= min.range)]))$fitted.values[which.min(x[which(x <= min.range)])]*l_y.min,
-                      lm((y[which(x <= mid.min.range)]) ~  (x[which(x <= mid.min.range)]))$fitted.values[which.min(x[which(x <= mid.min.range)])]*l_y.mid.min) /
-              sum(l_y.min, l_y.mid.min)
-          } else {
-
-            x0 <- y.min
-          }
+            if(l_y.min>1 && l_y.mid.min>1){
+                x0 <- sum(lm((y[which(x <= min.range)]) ~  (x[which(x <= min.range)]))$fitted.values[which.min(x[which(x <= min.range)])]*l_y.min,
+                          lm((y[which(x <= mid.min.range)]) ~  (x[which(x <= mid.min.range)]))$fitted.values[which.min(x[which(x <= mid.min.range)])]*l_y.mid.min) /
+                      sum(l_y.min, l_y.mid.min)
+            } else {
+                x0 <- y.min
+            }
         }
       } else {
         if(!is.null(type)){
@@ -561,7 +560,7 @@ NNS.reg = function (x, y,
     }
 
 
-    if(l_x.mid.max_unique > 1){
+    if(l_x.mid.max_unique > 1 && l_y.max > 5){
       if(dependence < stn){
         if(!is.null(type)){
           Dynamic.average.mid.max <- mode_class(y.max)
@@ -569,12 +568,12 @@ NNS.reg = function (x, y,
         } else {
           Dynamic.average.mid.max <-  tryCatch(lm(y[which(x >= max.range)] ~ 0 + x[which(x >= max.range)], offset = rep(tail(regression.points$y, 1), length(y[which(x >= max.range)])))$fitted[which.min(x[which(x >= max.range)])] + (mid.max.range - min(x[which(x >= max.range)])) * lm(y[which(x >= max.range)] ~  0 + x[which(x >= max.range)], offset = rep(tail(regression.points$y, 1), length(y[which(x >= max.range)])))$coef[1],
                                                error = function(e) NA)
-          if(l_y.max>1 && l_y.mid.max>1){
-            x.max <- sum(lm(y[which(x >= max.range)] ~ x[which(x >= max.range)])$fitted.values[which.max(x[which(x >= max.range)])]*l_y.max,
-                         lm(y[which(x >= mid.max.range)] ~ x[which(x >= mid.max.range)])$fitted.values[which.max(x[which(x >= mid.max.range)])]*l_y.mid.max) /
-              sum(l_y.max, l_y.mid.max)
+          if(l_y.max > 1 && l_y.mid.max > 1){
+              x.max <- sum(lm(y[which(x >= max.range)] ~ x[which(x >= max.range)])$fitted.values[which.max(x[which(x >= max.range)])]*l_y.max,
+                           lm(y[which(x >= mid.max.range)] ~ x[which(x >= mid.max.range)])$fitted.values[which.max(x[which(x >= mid.max.range)])]*l_y.mid.max) /
+                       sum(l_y.max, l_y.mid.max)
           } else{
-            x.max <- y.max
+              x.max <- y.max
           }
         }
       } else {
@@ -688,7 +687,11 @@ NNS.reg = function (x, y,
   coef.interval <- findInterval(x, Regression.Coefficients[ , (X.Lower.Range)], left.open = FALSE)
   reg.interval <- findInterval(x, regression.points[, x], left.open = FALSE)
 
-  estimate <- ((x - regression.points[reg.interval, x]) * Regression.Coefficients[coef.interval, Coefficient]) + regression.points[reg.interval, y]
+  if(!is.null(order) && is.character(order)){
+      estimate <- y
+  } else{
+      estimate <- ((x - regression.points[reg.interval, x]) * Regression.Coefficients[coef.interval, Coefficient]) + regression.points[reg.interval, y]
+  }
 
   if(!is.null(point.est)){
     coef.point.interval <- findInterval(point.est, Regression.Coefficients[ , (X.Lower.Range)], left.open = FALSE, rightmost.closed = TRUE)
@@ -724,7 +727,6 @@ NNS.reg = function (x, y,
 
   fitted$y.hat[is.na(fitted$y.hat)] <- mode(na.omit(fitted$y.hat))
 
-
   Values <- cbind(x, Fitted = fitted[ , y.hat], Actual = fitted[ , y], Difference = fitted[ , y.hat] - fitted[ , y],  Accuracy = abs(round(fitted[ , y.hat]) - fitted[ , y]))
 
   deg.fr <- length(y) - 2
@@ -738,33 +740,32 @@ NNS.reg = function (x, y,
   fitted <- cbind(fitted, gradient)
   fitted$residuals <- fitted$y.hat - fitted$y
 
-  bias <- fitted
-  data.table::setkey(bias, x)
+  if(dependence < stn){
+      bias <- fitted
+      data.table::setkey(bias, x)
 
-  bias <- bias[, mode(residuals)*-1, by = gradient]
+      bias <- bias[, mode(residuals)*-1, by = gradient]
 
-  fitted <- fitted[bias, on=.(gradient), y.hat := y.hat + V1]
+      fitted <- fitted[bias, on=.(gradient), y.hat := y.hat + V1]
 
-  bias[, bias_r := lapply(.SD, data.table::frollmean, n = 2, fill = 0, align = 'right'), .SDcols = 2]
-  bias[, bias_l := lapply(.SD, data.table::frollmean, n = 2, fill = 0, align = 'left'), .SDcols = 2]
+      bias[, bias_r := lapply(.SD, data.table::frollmean, n = 2, fill = 0, align = 'right'), .SDcols = 2]
+      bias[, bias_l := lapply(.SD, data.table::frollmean, n = 2, fill = 0, align = 'left'), .SDcols = 2]
 
-  bias[, bias := rowMeans(.SD, na.rm = TRUE), .SDcols = c("bias_r", "bias_l")]
+      bias[, bias := rowMeans(.SD, na.rm = TRUE), .SDcols = c("bias_r", "bias_l")]
 
-  bias[, bias_r := NULL]
-  bias[, bias_l := NULL]
+      bias[, bias_r := NULL]
+      bias[, bias_l := NULL]
 
+      bias <- data.table::rbindlist(list(bias, data.frame(t(c(0,0,0)))), use.names = FALSE)
 
-  bias <- data.table::rbindlist(list(bias, data.frame(t(c(0,0,0)))), use.names = FALSE)
-
-  if(!is.null(type)){
-    regression.points[, y := ifelse((y + bias$bias)%%1 < 0.5, floor(y + bias$bias), ceiling(y + bias$bias))]
-
-  } else {
-    regression.points[, y := y + bias$bias]
+      if(!is.null(type)){
+          regression.points[, y := ifelse((y + bias$bias)%%1 < 0.5, floor(y + bias$bias), ceiling(y + bias$bias))]
+      } else {
+          regression.points[, y := y + bias$bias]
+      }
   }
 
 
-
   regression.points$y <- pmin(regression.points$y, max(y))
   regression.points$y <- pmax(regression.points$y, min(y))
 
@@ -812,7 +813,11 @@ NNS.reg = function (x, y,
   coef.interval <- findInterval(x, Regression.Coefficients[ , (X.Lower.Range)], left.open = FALSE)
   reg.interval <- findInterval(x, regression.points[, x], left.open = FALSE)
 
-  estimate <- ((x - regression.points[reg.interval, x]) * Regression.Coefficients[coef.interval, Coefficient]) + regression.points[reg.interval, y]
+  if(!is.null(order) && is.character(order)){
+    estimate <- y
+  } else{
+    estimate <- ((x - regression.points[reg.interval, x]) * Regression.Coefficients[coef.interval, Coefficient]) + regression.points[reg.interval, y]
+  }
 
   if(!is.null(point.est)){
     coef.point.interval <- findInterval(point.est, Regression.Coefficients[ , (X.Lower.Range)], left.open = FALSE, rightmost.closed = TRUE)
@@ -823,10 +828,10 @@ NNS.reg = function (x, y,
 
     if(any(point.est > max(x) | point.est < min(x) ) & length(na.omit(point.est)) > 0){
       upper.slope <- mean(tail(Regression.Coefficients[, unique(Coefficient)], 2))
-      point.est.y[point.est>max(x)] <- (point.est[point.est>max(x)] - max(x)) * upper.slope +  regression.points[.N, y]   #mode(y[which.max(x)]))
+      point.est.y[point.est>max(x)] <- (point.est[point.est>max(x)] - max(x)) * upper.slope +  regression.points[.N, y]
 
       lower.slope <- mean(head(Regression.Coefficients[, unique(Coefficient)], 2))
-      point.est.y[point.est<min(x)] <- (point.est[point.est<min(x)] - min(x)) * lower.slope +  regression.points[1, y] #  mode(y[which.min(x)]))
+      point.est.y[point.est<min(x)] <- (point.est[point.est<min(x)] - min(x)) * lower.slope +  regression.points[1, y]
     }
 
     if(!is.null(type)){
@@ -868,7 +873,8 @@ NNS.reg = function (x, y,
     Prediction.Accuracy <- NULL
   }
 
-  if((sum((fitted[ , y.hat] - mean(y)) * (y - mean(y))) ^ 2)==0){
+
+  if((sum((fitted[ , y.hat] - mean(y)) * (y - mean(y))) ^ 2) == 0){
     R2 <- 1
   } else {
     R2 <- (sum((fitted[ , y.hat] - mean(y)) * (y - mean(y))) ^ 2) / (sum((y - mean(y)) ^ 2) * sum((fitted[ , y.hat] - mean(y)) ^ 2))
